https://github.com/pypa/sampleproject  

https://packaging.python.org/en/latest/tutorials/packaging-projects/  
https://packaging.python.org/en/latest/specifications/pyproject-toml/#declaring-project-metadata-the-project-table  
https://packaging.python.org/en/latest/specifications/pyproject-toml/#pyproject-toml-spec  
https://packaging.python.org/en/latest/guides/writing-pyproject-toml/  


https://setuptools.pypa.io/en/latest/userguide/pyproject_config.html  
https://setuptools.pypa.io/en/latest/userguide/pyproject_config.html#dynamic-metadata    

## Storing project metadata in pyproject.toml
https://peps.python.org/pep-0621/  
